@@ -9,17 +9,19 @@
 
 #include <sigc++/sigc++.h>
 
-void on_print(const std::string& str)
+void
+on_print(const std::string& str)
 {
   std::cout << str;
 }
 
-int main()
+int
+main()
 {
   sigc::signal<void(const std::string&)> signal_print;
-  
-  signal_print.connect( sigc::ptr_fun(&on_print) );
-  
+
+  signal_print.connect(sigc::ptr_fun(&on_print));
+
   signal_print.emit("hello world\n");
 
   return 0;
