@@ -9,9 +9,6 @@ namespace sigc
  * Functors which have all methods based on templates
  * should publicly inherit from this hint.
  *
- * adaptor_base inherits from the functor_base hint so
- * derived types should also have a result_type defined.
- *
  * Adaptors don't inherit from this type directly. They use
  * use sigc::adapts as a base type instead. sigc::adaptors
  * wraps arbitrary functor types as well as function pointers
@@ -19,7 +16,7 @@ namespace sigc
  *
  * @ingroup adaptors
  */
-struct adaptor_base : public functor_base
+struct adaptor_base
 {
 };
 
