@@ -1,6 +1,6 @@
 #ifndef _SIGC_ADAPTORS_COMPOSE_H_
 #define _SIGC_ADAPTORS_COMPOSE_H_
-#include <sigc++/adaptors/adaptor_trait.h>
+#include <sigc++/adaptors/adapts.h>
 
 namespace sigc
 {
@@ -43,11 +43,6 @@ namespace sigc
 template <class T_setter, class T_getter>
 struct compose1_functor : public adapts<T_setter>
 {
-  using adaptor_type = typename adapts<T_setter>::adaptor_type;
-  using setter_type = T_setter;
-  using getter_type = T_getter;
-  using result_type = typename adaptor_type::result_type;
-
   decltype(auto) operator()() { return this->functor_(get_()); }
 
   template <class... T_arg>
@@ -66,7 +61,7 @@ struct compose1_functor : public adapts<T_setter>
   {
   }
 
-  getter_type get_; // public, so that visit_each() can access it
+  T_getter get_; // public, so that visit_each() can access it
 };
 
 /** Adaptor that combines three functors.
@@ -82,12 +77,6 @@ struct compose1_functor : public adapts<T_setter>
 template <class T_setter, class T_getter1, class T_getter2>
 struct compose2_functor : public adapts<T_setter>
 {
-  using adaptor_type = typename adapts<T_setter>::adaptor_type;
-  using setter_type = T_setter;
-  using getter1_type = T_getter1;
-  using getter2_type = T_getter2;
-  using result_type = typename adaptor_type::result_type;
-
   decltype(auto) operator()() { return this->functor_(get1_(), get2_()); }
 
   template <class... T_arg>
@@ -108,8 +97,8 @@ struct compose2_functor : public adapts<T_setter>
   {
   }
 
-  getter1_type get1_; // public, so that visit_each() can access it
-  getter2_type get2_; // public, so that visit_each() can access it
+  T_getter1 get1_; // public, so that visit_each() can access it
+  T_getter2 get2_; // public, so that visit_each() can access it
 };
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
