@@ -1,7 +1,7 @@
 #ifndef _SIGC_ADAPTORS_RETYPE_H_
 #define _SIGC_ADAPTORS_RETYPE_H_
 
-#include <sigc++/adaptors/adaptor_trait.h>
+#include <sigc++/adaptors/adapts.h>
 #include <sigc++/functors/ptr_fun.h>
 #include <sigc++/functors/mem_fun.h>
 #include <sigc++/functors/slot.h>
@@ -61,9 +61,6 @@ namespace sigc
 template <class T_functor, class... T_type>
 struct retype_functor : public adapts<T_functor>
 {
-  using adaptor_type = typename adapts<T_functor>::adaptor_type;
-  using result_type = typename adapts<T_functor>::result_type;
-
   template <class... T_arg>
   decltype(auto) operator()(T_arg... _A_a)
   {
