@@ -21,10 +21,11 @@
 
 #include <sigc++config.h>
 
+namespace sigc
+{
 
-namespace sigc {
-
-namespace internal {
+namespace internal
+{
 
 template <class>
 struct member_method_is_const;
@@ -53,7 +54,6 @@ struct member_method_is_const<T_result (T_obj::*)(T_arg...) const volatile>
   constexpr static bool value = true;
 };
 
-
 template <class>
 struct member_method_is_volatile;
 
@@ -81,8 +81,7 @@ struct member_method_is_volatile<T_result (T_obj::*)(T_arg...) const volatile>
   constexpr static bool value = true;
 };
 
-
-//member method class:
+// member method class:
 
 template <class T_result, class... T_arg>
 struct member_method_class
@@ -90,31 +89,30 @@ struct member_method_class
 };
 
 template <class T_obj, class T_result, class... T_arg>
-struct member_method_class<T_result(T_obj::*)(T_arg...)>
+struct member_method_class<T_result (T_obj::*)(T_arg...)>
 {
   using type = T_obj;
 };
 
 template <class T_obj, class T_result, class... T_arg>
-struct member_method_class<T_result(T_obj::*)(T_arg...) volatile>
+struct member_method_class<T_result (T_obj::*)(T_arg...) volatile>
 {
   using type = T_obj;
 };
 
 template <class T_obj, class T_result, class... T_arg>
-struct member_method_class<T_result(T_obj::*)(T_arg...) const>
+struct member_method_class<T_result (T_obj::*)(T_arg...) const>
 {
   using type = T_obj;
 };
 
 template <class T_obj, class T_result, class... T_arg>
-struct member_method_class<T_result(T_obj::*)(T_arg...) const volatile>
+struct member_method_class<T_result (T_obj::*)(T_arg...) const volatile>
 {
   using type = T_obj;
 };
 
-
-//member method result:
+// member method result:
 
 template <class T_result, class... T_arg>
 struct member_method_result
@@ -122,25 +120,25 @@ struct member_method_result
 };
 
 template <class T_obj, class T_result, class... T_arg>
-struct member_method_result<T_result(T_obj::*)(T_arg...)>
+struct member_method_result<T_result (T_obj::*)(T_arg...)>
 {
   using type = T_result;
 };
 
 template <class T_obj, class T_result, class... T_arg>
-struct member_method_result<T_result(T_obj::*)(T_arg...) volatile>
+struct member_method_result<T_result (T_obj::*)(T_arg...) volatile>
 {
   using type = T_result;
 };
 
 template <class T_obj, class T_result, class... T_arg>
-struct member_method_result<T_result(T_obj::*)(T_arg...) const>
+struct member_method_result<T_result (T_obj::*)(T_arg...) const>
 {
   using type = T_result;
 };
 
 template <class T_obj, class T_result, class... T_arg>
-struct member_method_result<T_result(T_obj::*)(T_arg...) const volatile>
+struct member_method_result<T_result (T_obj::*)(T_arg...) const volatile>
 {
   using type = T_result;
 };
