@@ -19,7 +19,8 @@
 #ifndef _SIGC_REFERENCE_WRAPPER_H_
 #define _SIGC_REFERENCE_WRAPPER_H_
 
-namespace sigc {
+namespace sigc
+{
 
 template <class T_type>
 struct unwrap_reference
@@ -28,24 +29,30 @@ struct unwrap_reference
 };
 
 template <class T_type>
-struct unwrap_reference<std::reference_wrapper<T_type> >
+struct unwrap_reference<std::reference_wrapper<T_type>>
 {
   using type = T_type&;
 };
 
 template <class T_type>
-struct unwrap_reference<std::reference_wrapper<const T_type> >
+struct unwrap_reference<std::reference_wrapper<const T_type>>
 {
   using type = const T_type&;
 };
 
 template <class T_type>
-T_type& unwrap(const std::reference_wrapper<T_type>& v)
-{ return v; }
+T_type&
+unwrap(const std::reference_wrapper<T_type>& v)
+{
+  return v;
+}
 
 template <class T_type>
-const T_type& unwrap(const std::reference_wrapper<const T_type>& v)
-{ return v; }
+const T_type&
+unwrap(const std::reference_wrapper<const T_type>& v)
+{
+  return v;
+}
 
 } /* namespace sigc */
 
