@@ -263,7 +263,6 @@ struct slot_iterator_buf
   using pointer = T_result*;
 
   using emitter_type = T_emitter;
-  using result_type = T_result;
   using slot_type = typename T_emitter::slot_type;
 
   using iterator_type = signal_impl::const_iterator_type;
@@ -327,7 +326,7 @@ struct slot_iterator_buf
 private:
   iterator_type i_;
   const emitter_type* c_;
-  mutable result_type r_;
+  mutable T_result r_;
   mutable bool invoked_;
 };
 
@@ -341,7 +340,6 @@ struct slot_iterator_buf<T_emitter, void>
   using iterator_category = std::bidirectional_iterator_tag;
 
   using emitter_type = T_emitter;
-  using result_type = void;
   using slot_type = typename T_emitter::slot_type;
 
   using iterator_type = signal_impl::const_iterator_type;
@@ -416,7 +414,6 @@ struct slot_reverse_iterator_buf
   using pointer = T_result*;
 
   using emitter_type = T_emitter;
-  using result_type = T_result;
   using slot_type = typename T_emitter::slot_type;
 
   using iterator_type = signal_impl::const_iterator_type;
@@ -483,7 +480,7 @@ struct slot_reverse_iterator_buf
 private:
   iterator_type i_;
   const emitter_type* c_;
-  mutable result_type r_;
+  mutable T_result r_;
   mutable bool invoked_;
 };
 
@@ -497,7 +494,6 @@ struct slot_reverse_iterator_buf<T_emitter, void>
   using iterator_category = std::bidirectional_iterator_tag;
 
   using emitter_type = T_emitter;
-  using result_type = void;
   using slot_type = typename T_emitter::slot_type;
 
   using iterator_type = signal_impl::const_iterator_type;
@@ -560,6 +556,37 @@ private:
   mutable bool invoked_;
 };
 
+/** Temporary slot list used during signal emission.
+ *  Through evolution this class is slightly misnamed.  It is now
+ *  an index into the slot_list passed into it.  It simply keeps track
+ *  of where the end of this list was at construction, and pretends that's
+ *  the end of your list.  This way you may connect during emission without
+ *  inadvertently entering an infinite loop, as well as make other
+ *  modifications to the slot_list at your own risk.
+ */
+struct temp_slot_list
+{
+  using slot_list = signal_impl::slot_list;
+  using iterator = signal_impl::iterator_type;
+  using const_iterator = signal_impl::const_iterator_type;
+
+  temp_slot_list(slot_list& slots) : slots_(slots)
+  {
+    placeholder = slots_.insert(slots_.end(), slot_base());
+  }
+
+  ~temp_slot_list() { slots_.erase(placeholder); }
+
+  iterator begin() { return slots_.begin(); }
+  iterator end() { return placeholder; }
+  const_iterator begin() const { return slots_.begin(); }
+  const_iterator end() const { return placeholder; }
+
+private:
+  slot_list& slots_;
+  slot_list::iterator placeholder;
+};
+
 /** Abstracts signal emission.
  * This template implements the emit() function of signal_with_accumulator.
  * Template specializations are available to optimize signal
@@ -570,7 +597,6 @@ template <class T_return, class T_accumulator, class... T_arg>
 struct signal_emit
 {
   using self_type = signal_emit<T_return, T_accumulator, T_arg...>;
-  using result_type = typename T_accumulator::result_type;
   using slot_type = slot<T_return(T_arg...)>;
   using slot_iterator_buf_type = internal::slot_iterator_buf<self_type, T_return>;
   using slot_reverse_iterator_buf_type = internal::slot_reverse_iterator_buf<self_type, T_return>;
@@ -653,7 +679,6 @@ template <class T_return, class... T_arg>
 struct signal_emit<T_return, void, T_arg...>
 {
   using self_type = signal_emit<T_return, void, T_arg...>;
-  using result_type = T_return;
   using slot_type = slot<T_return(T_arg...)>;
   using iterator_type = signal_impl::const_iterator_type;
   using call_type = typename slot_type::call_type;
@@ -759,7 +784,6 @@ template <class... T_arg>
 struct signal_emit<void, void, T_arg...>
 {
   using self_type = signal_emit<void, void, T_arg...>;
-  using result_type = void;
   using slot_type = slot<void(T_arg...)>;
   using iterator_type = signal_impl::const_iterator_type;
   using call_type = typename slot_type::call_type;
@@ -843,7 +867,6 @@ class signal_with_accumulator : public signal_base
 {
 public:
   using emitter_type = internal::signal_emit<T_return, T_accumulator, T_arg...>;
-  using result_type = typename emitter_type::result_type;
   using slot_type = slot<T_return(T_arg...)>;
   using slot_list_type = slot_list<slot_type>;
   using iterator = typename slot_list_type::iterator;
@@ -920,6 +943,8 @@ public:
    */
   decltype(auto) make_slot() const
   {
+    //TODO: Instead use std::result_of<> on the static emitter_type::emit()
+    using result_type = typename internal::member_method_result<decltype(&signal_with_accumulator::emit)>::type;
     return bound_mem_functor<result_type (signal_with_accumulator::*)(type_trait_take_t<T_arg>...)
                                const,
       type_trait_take_t<T_arg>...>(*this, &signal_with_accumulator::emit);
@@ -1016,18 +1041,16 @@ public:
    * from the results of the slot invokations. The iterators' operator*()
    * executes the slot. The return value is buffered, so that in an expression
    * like @code a = (*i) * (*i); @endcode the slot is executed only once.
-   * The accumulator must define its return value as @p result_type.
    *
    * @par Example 1:
    * This accumulator calculates the arithmetic mean value:
    * @code
    * struct arithmetic_mean_accumulator
    * {
-   *   using result_type = double;
    *   template<typename T_iterator>
-   *   result_type operator()(T_iterator first, T_iterator last) const
+   *   double operator()(T_iterator first, T_iterator last) const
    *   {
-   *     result_type value_ = 0;
+   *     double value_ = 0;
    *     int n_ = 0;
    *     for (; first != last; ++first, ++n_)
    *       value_ += *first;
@@ -1041,9 +1064,8 @@ public:
    * @code
    * struct interruptable_accumulator
    * {
-   *   using result_type = bool;
    *   template<typename T_iterator>
-   *   result_type operator()(T_iterator first, T_iterator last) const
+   *   bool operator()(T_iterator first, T_iterator last) const
    *   {
    *     for (; first != last; ++first, ++n_)
    *       if (!*first) return false;
