@@ -22,15 +22,15 @@
 namespace sigc
 {
 
-trackable::trackable() noexcept
-: callback_list_(nullptr)
-{}
+trackable::trackable() noexcept : callback_list_(nullptr)
+{
+}
 
 /* Don't copy the notification list.
    The objects watching src don't need to be notified when the new object dies. */
-trackable::trackable(const trackable& /*src*/) noexcept
-: callback_list_(nullptr)
-{}
+trackable::trackable(const trackable& /*src*/) noexcept : callback_list_(nullptr)
+{
+}
 
 // Don't move the notification list.
 // The objects watching src don't need to be notified when the new object dies.
@@ -38,25 +38,26 @@ trackable::trackable(const trackable& /*src*/) noexcept
 //
 // If trackable's move constructor is modified, check if Glib::Object's
 // move constructor should be modified similarly.
-trackable::trackable(trackable&& src)
-: callback_list_(nullptr)
+trackable::trackable(trackable&& src) : callback_list_(nullptr)
 {
   src.notify_callbacks();
 }
 
-trackable& trackable::operator=(const trackable& src)
+trackable&
+trackable::operator=(const trackable& src)
 {
-  if(this != &src)
-    notify_callbacks(); //Make sure that we have finished with existing stuff before replacing it.
-  
+  if (this != &src)
+    notify_callbacks(); // Make sure that we have finished with existing stuff before replacing it.
+
   return *this;
 }
 
-trackable& trackable::operator=(trackable&& src)
+trackable&
+trackable::operator=(trackable&& src)
 {
-  if(this != &src)
+  if (this != &src)
   {
-    notify_callbacks(); //Make sure that we have finished with existing stuff before replacing it.
+    notify_callbacks(); // Make sure that we have finished with existing stuff before replacing it.
     src.notify_callbacks(); // src probably becomes useless.
   }
   return *this;
@@ -67,25 +68,29 @@ trackable::~trackable()
   notify_callbacks();
 }
 
-void trackable::add_destroy_notify_callback(notifiable* data, func_destroy_notify func) const
+void
+trackable::add_destroy_notify_callback(notifiable* data, func_destroy_notify func) const
 {
   callback_list()->add_callback(data, func);
 }
 
-void trackable::remove_destroy_notify_callback(notifiable* data) const
+void
+trackable::remove_destroy_notify_callback(notifiable* data) const
 {
   callback_list()->remove_callback(data);
 }
 
-void trackable::notify_callbacks()
+void
+trackable::notify_callbacks()
 {
   if (callback_list_)
-    delete callback_list_; //This invokes all of the callbacks.
+    delete callback_list_; // This invokes all of the callbacks.
 
   callback_list_ = nullptr;
 }
 
-internal::trackable_callback_list* trackable::callback_list() const
+internal::trackable_callback_list*
+trackable::callback_list() const
 {
   if (!callback_list_)
     callback_list_ = new internal::trackable_callback_list;
@@ -93,7 +98,6 @@ internal::trackable_callback_list* trackable::callback_list() const
   return callback_list_;
 }
 
-      
 namespace internal
 {
 
@@ -102,41 +106,50 @@ trackable_callback_list::~trackable_callback_list()
   clearing_ = true;
 
   for (auto& callback : callbacks_)
+  {
     if (callback.func_)
       callback.func_(callback.data_);
+  }
 }
 
-void trackable_callback_list::add_callback(notifiable* data, func_destroy_notify func)
+void
+trackable_callback_list::add_callback(notifiable* data, func_destroy_notify func)
 {
-  if (!clearing_)  // TODO: Is it okay to silently ignore attempts to add dependencies when the list is being cleared?
-                   //       I'd consider this a serious application bug, since the app is likely to segfault.
-                   //       But then, how should we handle it? Throw an exception? Martin.
+  // TODO: Is it okay to silently ignore attempts to add dependencies when the list
+  // is being cleared?
+  // I'd consider this a serious application bug, since the app is likely to segfault.
+  // But then, how should we handle it? Throw an exception? Martin.
+  if (!clearing_)
     callbacks_.push_back(trackable_callback(data, func));
 }
 
-void trackable_callback_list::clear()
+void
+trackable_callback_list::clear()
 {
   clearing_ = true;
 
   for (auto& callback : callbacks_)
-    if (callback.func_) 
+  {
+    if (callback.func_)
       callback.func_(callback.data_);
+  }
 
   callbacks_.clear();
 
   clearing_ = false;
 }
 
-void trackable_callback_list::remove_callback(notifiable* data)
+void
+trackable_callback_list::remove_callback(notifiable* data)
 {
-  for (callback_list::iterator i = callbacks_.begin(); i != callbacks_.end(); ++i)
+  for (auto i = callbacks_.begin(); i != callbacks_.end(); ++i)
   {
     auto& callback = *i;
     if (callback.data_ == data && callback.func_ != nullptr)
     {
-      //Don't remove a list element while the list is being cleared.
-      //It could invalidate the iterator in ~trackable_callback_list() or clear().
-      //But it may be necessary to invalidate the callback. See bug 589202.
+      // Don't remove a list element while the list is being cleared.
+      // It could invalidate the iterator in ~trackable_callback_list() or clear().
+      // But it may be necessary to invalidate the callback. See bug 589202.
       if (clearing_)
         callback.func_ = nullptr;
       else
