@@ -9,17 +9,18 @@ namespace
 {
 std::ostringstream result_stream;
 
-int ident(int i)
+int
+ident(int i)
 {
   return i;
 }
 
-template<typename T>
+template <typename T>
 struct min_accum
 {
   using result_type = T;
 
-  template<class I>
+  template <class I>
   typename std::iterator_traits<I>::value_type operator()(I i1, I i2)
   {
     return *std::min_element(i1, i2);
@@ -28,7 +29,8 @@ struct min_accum
 
 } // end anonymous namespace
 
-int main(int argc, char* argv[])
+int
+main(int argc, char* argv[])
 {
   auto util = TestUtilities::get_instance();
 
