@@ -22,7 +22,7 @@ std::ostringstream result_stream;
 struct arithmetic_mean_accumulator
 {
   using result_type = double;
-  template<typename T_iterator>
+  template <typename T_iterator>
   double operator()(T_iterator first, T_iterator last) const
   {
     double value_ = 0;
@@ -33,11 +33,11 @@ struct arithmetic_mean_accumulator
   }
 };
 
-template<class Ret>
+template <class Ret>
 struct vector_accumulator
 {
   using result_type = std::vector<Ret>;
-  template<typename T_iterator>
+  template <typename T_iterator>
   result_type operator()(T_iterator first, T_iterator last) const
   {
     result_type vec;
@@ -47,14 +47,16 @@ struct vector_accumulator
   }
 };
 
-int foo(int i)
+int
+foo(int i)
 {
   const int result = 3 * i + 1;
   result_stream << "foo: " << result << ", ";
   return result;
 }
 
-int bar(double i)
+int
+bar(double i)
 {
   const int result = 5 * int(i) - 3;
   result_stream << "bar: " << result << ", ";
@@ -71,10 +73,11 @@ struct A : public sigc::trackable
   }
 };
 
-void test_empty_signal()
+void
+test_empty_signal()
 {
   sigc::signal<int(int)>::accumulated<arithmetic_mean_accumulator> sig;
-  sigc::signal<int(int)>::accumulated<vector_accumulator<int> > sig_vec;
+  sigc::signal<int(int)>::accumulated<vector_accumulator<int>> sig_vec;
 
   result_stream << "Result (empty slot list): " << sig(0);
   util->check_result(result_stream, "Result (empty slot list): -1");
@@ -83,7 +86,8 @@ void test_empty_signal()
   util->check_result(result_stream, "Vector result (empty slot list): empty");
 }
 
-void test_mean()
+void
+test_mean()
 {
   sigc::signal<int(int)>::accumulated<arithmetic_mean_accumulator> sig;
 
@@ -93,45 +97,46 @@ void test_mean()
   sig.connect(sigc::ptr_fun(&bar));
 
   double dres = sig(1);
-  result_stream << "Mean accumulator: Result (i=1): "
-                << std::fixed << std::setprecision(3) << dres;
-  util->check_result(result_stream,
-    "foo: 4, A::foo: 6, bar: 2, Mean accumulator: Result (i=1): 4.000");
+  result_stream << "Mean accumulator: Result (i=1): " << std::fixed << std::setprecision(3) << dres;
+  util->check_result(
+    result_stream, "foo: 4, A::foo: 6, bar: 2, Mean accumulator: Result (i=1): 4.000");
 
   dres = sig(11);
-  result_stream << "Mean accumulator: Plain Result (i=11): "
-                << std::fixed << std::setprecision(3) << dres;
-  util->check_result(result_stream,
-    "foo: 34, A::foo: 206, bar: 52, Mean accumulator: Plain Result (i=11): 97.333");
+  result_stream << "Mean accumulator: Plain Result (i=11): " << std::fixed << std::setprecision(3)
+                << dres;
+  util->check_result(
+    result_stream, "foo: 34, A::foo: 206, bar: 52, Mean accumulator: Plain Result (i=11): 97.333");
 }
 
-void test_vector_accumulator()
+void
+test_vector_accumulator()
 {
-  sigc::signal<int(int)>::accumulated<vector_accumulator<int> > sig_vec;
+  sigc::signal<int(int)>::accumulated<vector_accumulator<int>> sig_vec;
 
   A a;
   sig_vec.connect(sigc::ptr_fun(&foo));
   sig_vec.connect(sigc::mem_fun(a, &A::foo));
   sig_vec.connect(sigc::ptr_fun(&bar));
-  
+
   auto res1 = sig_vec(1);
   result_stream << "Vector accumulator: Result (i=1): ";
   for (auto num : res1)
     result_stream << num << " ";
-  util->check_result(result_stream,
-    "foo: 4, A::foo: 6, bar: 2, Vector accumulator: Result (i=1): 4 6 2 ");
+  util->check_result(
+    result_stream, "foo: 4, A::foo: 6, bar: 2, Vector accumulator: Result (i=1): 4 6 2 ");
 
   auto res3 = sig_vec(3);
   result_stream << "Vector accumulator: Result (i=3): ";
   for (auto num : res3)
     result_stream << num << " ";
-  util->check_result(result_stream,
-    "foo: 10, A::foo: 46, bar: 12, Vector accumulator: Result (i=3): 10 46 12 ");
+  util->check_result(
+    result_stream, "foo: 10, A::foo: 46, bar: 12, Vector accumulator: Result (i=3): 10 46 12 ");
 }
 
 } // end anonymous namespace
 
-int main(int argc, char* argv[])
+int
+main(int argc, char* argv[])
 {
   util = TestUtilities::get_instance();
 
