@@ -22,6 +22,7 @@
 #include <sstream>
 #include <cstdlib>
 #include <sigc++/signal.h>
+#include <sigc++/adaptors/adapts.h>
 
 // SIGCTEST_CASE 1  Assume that class sigc::visitor has not been implemented.
 //                  Don't test with MyClass2, which is expected to fail in this case.
@@ -83,9 +84,7 @@ namespace ns1
 template <class T_functor>
 struct MyAdaptor1 : public sigc::adapts<T_functor>
 {
-  using result_type = typename sigc::functor_trait<T_functor>::result_type;
-
-  result_type operator()() const
+  decltype(auto) operator()() const
   {
     result_stream << "MyAdaptor1()() ";
     return this->functor_();
